<?php
/*

Copyright 2013 Marcin Pietrzak (marcin@iworks.pl)

this program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as 
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

 */

if ( !defined( 'WPINC' ) ) {
    die;
}

class iWorks_WordCamp_Wroclaw_2013_Widget extends WP_Widget
{
    private $textdomain;
    private $dimentions;
    private $backgrounds;

    public function __construct()
    {
        $this->textdomain = '2013.wroclaw.wordcamp.org';
        parent::__construct(
            'wordcamp-wroclaw',
            __( 'WordCamp Wrocław 2013', $this->texdomain ),
            array(
                'description' => __( 'Widget pozwala na pokazanie grafiki zachęcającej do udziału we Wrocławskim WordCampie. ', $this->textdomain ),
            )
        );

        $this->dimentions = array(
            'beda-hiszpanki' => 'będą Hiszpanki?',
            'bede-tam' => 'Będę tam!',
            'hejter' => 'hejter nr 1',
            'varnish' => 'I\'m Varnish',
            'jade-na-aftera' => 'jadę na aftera',
            'jeste-spikere' => 'jestę spikerę*',
            'nie-ogarniam' => 'nie ogarniam!',
            'ogarniam' => 'Ogarniam',
            'organizator' => 'Organizator',
            'pawel' => 'Paweł! Paweł!',
            'prelegent' => 'Prelegent',
            'sponsor' => 'Sponsor',
            'sypie-kasoom' => 'sypię kasoom',
            'tylko-pacze' => 'tylko pacze!',
            'uczestnik' => 'Uczestnik',
            '' => 'WordCamp',
        );

        $this->backgrounds = array(
            'transparent' => 'przezroczyste',
            '' => 'szare',
        );

    }

    public function widget( $args, $instance )
    {
        $title = apply_filters( 'widget_title', $instance['title'] );
        echo $args['before_widget'];
        if ( ! empty( $title ) ) {
            echo $args['before_title'] . $title . $args['after_title'];
        }
        echo '<a href="http://2013.wroclaw.wordcamp.org/">';
        echo '<img src="http://2013.wroclaw.wordcamp.org/files/2013/09/wordcamp-wroclaw-2013';
        if ( isset( $instance[ 'logo' ] ) && !empty( $instance[ 'logo' ] ) ) {
            echo '_';
            echo $instance[ 'logo' ];
        }
        echo '-250x250';
        if ( isset( $instance[ 'background' ] ) && !empty( $instance[ 'background' ] ) ) {
            echo '-';
            echo $instance[ 'background' ];
        }
        echo '.png" alt="" width="250" height="250" />';
        echo '</a>';
        echo $args['after_widget'];

    }

    public function form( $instance )
    {
        if ( isset( $instance[ 'title' ] ) ) {
            $title = $instance[ 'title' ];
        }
        else {
            $title = __( 'WordCamp Wrocław 2013', $this->texdomain );
        }
?>
        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
<?php
        if ( isset( $instance[ 'logo' ] ) ) {
            $logo = $instance[ 'logo' ];
        }
        else {
            $logo = '';
        }
?>
        <p>
            <label for="<?php echo $this->get_field_id( 'logo' ); ?>"><?php _e( 'Logo:' ); ?></label>
            <ul>
<?php
        foreach( $this->dimentions as $dimention => $label ) {
            $id = 'iworks_'.crc32( $this->get_field_id( 'logo' ) . $dimention );
            printf(
                '<li><input name="%s" type="radio" value="%s" id="%s" %s /><label for="%s"> %s</label></li>',
                $this->get_field_name( 'logo' ),
                $dimention,
                $id,
                checked( $dimention, $logo, false ),
                $id,
                $label
            );
        }
?>
        </ul>
        </p>
<?php
        if ( isset( $instance[ 'background' ] ) ) {
            $background = $instance[ 'background' ];
        }
        else {
            $background = '';
        }
?>
        <p>
            <label for="<?php echo $this->get_field_id( 'background' ); ?>"><?php _e( 'Tło:' ); ?></label>
            <ul>
<?php
        foreach( $this->backgrounds as $dimention => $label ) {
            $id = 'iworks_'.crc32( $this->get_field_id( 'background' ) . $dimention );
            printf(
                '<li><input name="%s" type="radio" value="%s" id="%s" %s /><label for="%s"> %s</label></li>',
                $this->get_field_name( 'background' ),
                $dimention,
                $id,
                checked( $dimention, $background, false ),
                $id,
                $label
            );
        }
?>
        </ul>
        </p>
<?php
    }

    public function update( $new_instance, $old_instance )
    {
        $instance = array();
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['logo'] = ( ! empty( $new_instance['logo'] ) ) ? strip_tags( $new_instance['logo'] ) : '';
        $instance['background'] = ( ! empty( $new_instance['background'] ) ) ? strip_tags( $new_instance['background'] ) : '';

        return $instance;

    }
}
/*
wordcamp-wroclaw-2013_250x250.png
wordcamp-wroclaw-2013-250x250-transparent.png
wordcamp-wroclaw-2013_beda-hiszpanki-250x250.png
wordcamp-wroclaw-2013_beda-hiszpanki-250x250-transparent.png
wordcamp-wroclaw-2013_bede-tam-250x250.png
wordcamp-wroclaw-2013_bede-tam-250x250-transparent.png
wordcamp-wroclaw-2013_hejter-250x250.png
wordcamp-wroclaw-2013_hejter-250x250-transparent.png
wordcamp-wroclaw-2013_jade-na-aftera-250x250.png
wordcamp-wroclaw-2013_jade-na-aftera-250x250-transparent.png
wordcamp-wroclaw-2013_jeste-spikere-250x250.png
wordcamp-wroclaw-2013_jeste-spikere-250x250-transparent.png
wordcamp-wroclaw-2013_nie-ogarniam-250x250.png
wordcamp-wroclaw-2013_nie-ogarniam-250x250-transparent.png
wordcamp-wroclaw-2013_ogarniam-250x250.png
wordcamp-wroclaw-2013_ogarniam-250x250-transparent.png
wordcamp-wroclaw-2013_organizator-250x250.png
wordcamp-wroclaw-2013_organizator-250x250-transparent.png
wordcamp-wroclaw-2013_pawel-250x250.png
wordcamp-wroclaw-2013_pawel-250x250-transparent.png
wordcamp-wroclaw-2013_prelegent-250x250.png
wordcamp-wroclaw-2013_prelegent-250x250-transparent.png
wordcamp-wroclaw-2013_sponsor-250x250.png
wordcamp-wroclaw-2013_sponsor-250x250-transparent.png
wordcamp-wroclaw-2013_sypie-kasoom-250x250.png
wordcamp-wroclaw-2013_sypie-kasoom-250x250-transparent.png
wordcamp-wroclaw-2013_tylko-pacze-250x250.png
wordcamp-wroclaw-2013_tylko-pacze-250x250-transparent.png
wordcamp-wroclaw-2013_uczestnik-250x250.png
wordcamp-wroclaw-2013_uczestnik-250x250-transparent.png
wordcamp-wroclaw-2013_varnish-250x250.png
wordcamp-wroclaw-2013_varnish-250x250-transparent.png
*/
